@@ -104,6 +104,7 @@ public:
             : mstream( s ), mw( w ), msr( mw.showingRect() )
     {
     }
+    using ObjectImpVisitor::visit;
     void visit( const LineImp* imp );
     void visit( const PointImp* imp );
     void visit( const TextImp* imp );
@@ -787,7 +788,7 @@ void LatexExporter::run( const KigPart& doc, KigWidget& w )
         {
             // TODO: Polar grid
             // vertical lines...
-            double startingpoint = startingpoint = static_cast<double>( KDE_TRUNC( left ) );
+            double startingpoint = static_cast<double>( KDE_TRUNC( left ) );
             for ( double i = startingpoint; i < left+width; ++i )
             {
                 stream << "draw((" << i << "," << bottom << ")--(" << i << "," << bottom+height << "),gray);\n";
