@@ -82,9 +82,10 @@ void KigApplication::handleArgs( KCmdLineArgs* args )
 static int convertToNative( const KUrl& file, const QByteArray& outfile )
 {
   KComponentData maindata( KCmdLineArgs::aboutData() );
-  KLibrary* library = KLibLoader::self()->library( "kigpart", QLibrary::ExportExternalSymbolsHint );
+  KPluginLoader libraryLoader( "kigpart" );
+  QLibrary library( libraryLoader.fileName() );
   int ( *converterfunction )( const KUrl&, const QByteArray& );
-  converterfunction = ( int ( * )( const KUrl&, const QByteArray& ) ) library->resolveFunction( "convertToNative" );
+  converterfunction = ( int ( * )( const KUrl&, const QByteArray& ) ) library.resolve( "convertToNative" );
   if ( !converterfunction )
   {
     kError() << "Error: broken Kig installation: different library and application version !" << endl;
