@@ -408,6 +408,10 @@ const Coordinate calcConicLineIntersect( const ConicCartesianData& c,
     } else {
       t = -bbb + which*sqrt(discrim);
       t /= 2*aaa;
+      /* mp: this threshold test for a point at infinity allows to 
+       * solve Bug https://bugs.kde.org/show_bug.cgi?id=316693
+       */
+      if (fabs(t) > 1e15) return Coordinate::invalidCoord();
     }
 
     return l.a + t*(l.b - l.a);
